ZipupSdk class

Constructors

ZipupSdk()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(ZipupEventCallback callback) StreamSubscription<Map<String, dynamic>>?
close() Future<String?>
getConfig() Future<Map<String, dynamic>?>
{ userKey, userPhone, proxyUrl, safeArea: { top, bottom, left, right }? }
getEventStream() Stream<Map<String, dynamic>>?
init(String userKey, String userPhone, String proxyUrl) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() Future<String?>
removeEventListener() → void
test(String testUrl) Future<String?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited