MethodChannelZipupSdkFlutter class
An implementation of ZipupSdkFlutterPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- ZipupSdkFlutterPlatform
- MethodChannelZipupSdkFlutter
Constructors
Properties
- eventChannel → EventChannel
-
The event channel used to receive events from the native platform.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< String?> -
override
-
getConfig(
) → Future< Map< String, dynamic> ?> -
SDKClientConfig 형태: { userKey, userPhone, proxyUrl, safeArea: { top, bottom, left, right }? }
override
-
getEventStream(
) → Stream< Map< ?String, dynamic> > -
override
-
initSdk(
String userKey, String userPhone, String proxyUrl) → Future< String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
test(
String testUrl) → Future< String?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
viewZipupSDK(
) → Future< String?> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited