ZipupSdkFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ZipupSdkFlutterPlatform
Implementers

Constructors

ZipupSdkFlutterPlatform()
Constructs a ZipupSdkFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<String?>
getConfig() Future<Map<String, dynamic>?>
SDKClientConfig 형태: { userKey, userPhone, proxyUrl, safeArea: { top, bottom, left, right }? }
getEventStream() Stream<Map<String, dynamic>>?
initSdk(String userKey, String userPhone, String proxyUrl) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
test(String testUrl) Future<String?>
toString() String
A string representation of this object.
inherited
viewZipupSDK() Future<String?>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ZipupSdkFlutterPlatform
The default instance of ZipupSdkFlutterPlatform to use.
getter/setter pair