ZipupSdkFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ZipupSdkFlutterPlatform
Implementers

Constructors

ZipupSdkFlutterPlatform()
Constructs a ZipupSdkFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(String eventName) Future<String?>
close() Future<String?>
getEventStream() Stream<Map<String, dynamic>>?
getPlatformVersion() Future<String?>
getSdkName() Future<String?>
initSdk(String clientId, String clientSecret) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListeners(int count) Future<String?>
toString() String
A string representation of this object.
inherited
viewZipupSDK() Future<String?>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ZipupSdkFlutterPlatform
The default instance of ZipupSdkFlutterPlatform to use.
getter/setter pair